@@ -1,7 +1,7 @@
 package Mooish::Caller::Util;
 
 our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -27,6 +27,7 @@ sub _get_constructor_caller_or_callers {
 
     my $i = 0;
     my $j = 0;
+    my $skips = 0;
     while (1) {
         $i++;
         my @caller;
@@ -98,6 +99,9 @@ sub _get_constructor_caller_or_callers {
                             $caller[3] eq 'Moose::Object::new';
                         $wrappers_done++;
                     } else { # Mouse
+                        if ($] < 5.014) {
+                            next unless $skips++ >= 1;
+                        }
                         $wrappers_done++;
                     }
                 } else { # BUILDARGS
@@ -108,6 +112,9 @@ sub _get_constructor_caller_or_callers {
                         next if $caller[3] eq 'Moose::Object::new';
                         $wrappers_done++;
                     } else { # Mouse
+                        if ($] < 5.014) {
+                            next unless $skips++ >= 1;
+                        }
                         $wrappers_done++;
                     }
                 }
@@ -152,7 +159,7 @@ Mooish::Caller::Util - Get constructor caller from inside Mo/Moo/Moose/Mouse's B
 
 =head1 VERSION
 
-This document describes version 0.04 of Mooish::Caller::Util (from Perl distribution Mooish-Caller-Util), released on 2015-07-27.
+This document describes version 0.05 of Mooish::Caller::Util (from Perl distribution Mooish-Caller-Util), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
